Struct AlphaLast

#[repr(C)]
pub struct AlphaLast<A, C> { /* private fields */ }
A contiguous color with alpha last, preceded by other color components.

Layout

template<typename C, typename A>
struct AlphaLast {
  C color;
  A alpha;
}

Implementations

Source

impl<A, C> AlphaLast<A, C>

pub const fn with_color(alpha: A, color: C) -> Self

Creates a new instance of AlphaFirst with the given color and alpha components.

pub const fn alpha(&self) -> A
where A: Copy,

Returns the alpha component of this color.

pub const fn color(&self) -> C
where C: Copy,

Returns the color component of this color.

pub fn into_inner(self) -> (C, A)

Consumes and returns the color and alpha components of this color.

Source

impl AlphaLast<u8, Gray<u8>>

pub const fn new(gray: u8, alpha: u8) -> Self

Creates a new 8-bit grayscale color with alpha.

Source

impl AlphaLast<u16, Gray<u16>>

pub const fn new(gray: u16, alpha: u16) -> Self

Creates a new 16-bit grayscale color with alpha.

Source

impl AlphaLast<f32, Gray<f32>>

pub const fn new(gray: f32, alpha: f32) -> Self

Creates a new 32-bit floating-point grayscale color with alpha.

Source

impl AlphaLast<f32, Rgb<f32>>

pub const fn from_rgba(r: f32, g: f32, b: f32, a: f32) -> Self

Creates a new RGBA color from the individual components.

Examples
use gem::{alpha::HasAlpha, rgb::{HasRed, HasGreen, HasBlue, Rgbaf32}};

let color = Rgbaf32::from_rgba(1.0, 0.0, 0.0, 1.0);
assert_eq!(color.red(), 1.0);
assert_eq!(color.green(), 0.0);
assert_eq!(color.blue(), 0.0);
assert_eq!(color.alpha(), 1.0);