#[repr(C)]pub struct AlphaLast<A, C> { /* private fields */ }Expand description
A contiguous color with alpha last, preceded by other color components.
Layout
template<typename C, typename A>
struct AlphaLast {
C color;
A alpha;
}Implementations
Sourceimpl<A, C> AlphaLast<A, C>
impl<A, C> AlphaLast<A, C>
Sourcepub const fn with_color(alpha: A, color: C) -> Self
pub const fn with_color(alpha: A, color: C) -> Self
Creates a new instance of AlphaFirst with the given color and alpha components.
Sourcepub fn into_inner(self) -> (C, A)
pub fn into_inner(self) -> (C, A)
Consumes and returns the color and alpha components of this color.
Sourceimpl AlphaLast<f32, Rgb<f32>>
impl AlphaLast<f32, Rgb<f32>>
Sourcepub const fn from_rgba(r: f32, g: f32, b: f32, a: f32) -> Self
pub const fn from_rgba(r: f32, g: f32, b: f32, a: f32) -> Self
Creates a new RGBA color from the individual components.
Examples
use gem::{alpha::HasAlpha, rgb::{HasRed, HasGreen, HasBlue, Rgbaf32}};
let color = Rgbaf32::from_rgba(1.0, 0.0, 0.0, 1.0);
assert_eq!(color.red(), 1.0);
assert_eq!(color.green(), 0.0);
assert_eq!(color.blue(), 0.0);
assert_eq!(color.alpha(), 1.0);Trait Implementations
Sourceimpl<A, C> HasAlpha for AlphaLast<A, C>where
A: Copy,
impl<A, C> HasAlpha for AlphaLast<A, C>where
A: Copy,
Sourceimpl<A, C> HasBlue for AlphaLast<A, C>
impl<A, C> HasBlue for AlphaLast<A, C>
Sourceimpl<A, C> HasGreen for AlphaLast<A, C>
impl<A, C> HasGreen for AlphaLast<A, C>
Sourceimpl<A, C> HasRed for AlphaLast<A, C>
impl<A, C> HasRed for AlphaLast<A, C>
Sourceimpl<A: Ord, C: Ord> Ord for AlphaLast<A, C>
impl<A: Ord, C: Ord> Ord for AlphaLast<A, C>
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl<A: PartialOrd, C: PartialOrd> PartialOrd for AlphaLast<A, C>
impl<A: PartialOrd, C: PartialOrd> PartialOrd for AlphaLast<A, C>
impl<A: Copy, C: Copy> Copy for AlphaLast<A, C>
impl<A: Eq, C: Eq> Eq for AlphaLast<A, C>
impl<A, C> Pod for AlphaLast<A, C>where
A: Pod,
C: Pod,
impl<A, C> StructuralPartialEq for AlphaLast<A, C>